@@ -1,6 +1,7 @@
 package MooX::Keyword;
-use 5.006; use strict; use warnings; our $VERSION = '0.01'; 
+use 5.006; use strict; use warnings; our $VERSION = '0.02'; 
 use MooX::ReturnModifiers; use Anonymous::Object;
+use feature qw/state/;
 
 sub import {
 	my ( $package, %import ) = (shift, ref $_[0] ? %{ $_[0] } : @_);
@@ -8,7 +9,19 @@ sub import {
 	my $moo = Anonymous::Object->new(object_name => 'MooX::Keyword')->hash_to_object_context({
 		return_modifiers( $target )
 	}); # *\o/*
+	
+	if ($import{extends}) {
+		$moo->extends($import{extends});
+		%import = $import{extends}->keyword_meta;		
+		delete $import{extends};
+	}
+
+	keyword($target, $moo, 'keyword_meta', { builder => sub {
+		my $m = shift;
+		return %import;
+	}});
 	keyword($target, $moo, $_, $import{$_}) for keys %import;
+	
 	return 1;
 }
 
@@ -33,7 +46,7 @@ MooX::Keyword - The great new MooX::Keyword!
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
@@ -64,7 +77,7 @@ Quick summary of what the module does.
 
 	...
 
-	my $night = Moon->new(
+	my $moon = Moon->new(
 		shine => 211,
 		light => [{ ... }]
 	);
@@ -72,6 +85,18 @@ Quick summary of what the module does.
 	$moon->shine(633);
 	$moon->light;
 
+	...
+
+	package Night 
+
+	use Moo;
+	use MooX::Keyword extends => Moon;
+
+	star polaris  => (
+		is => 'ro'
+	);
+
+
 beta.
 
 =head1 AUTHOR
